"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var geometry_1 = require("./geometry");
/**
 * Discrete Frechet distance between 2 curves
 * based on http://www.kr.tuwien.ac.at/staff/eiter/et-archive/cdtr9464.pdf
 * @param curve1
 * @param curve2
 */
var frechetDist = function (curve1, curve2) {
    var results = [];
    for (var i = 0; i < curve1.length; i++) {
        results.push([]);
        for (var j = 0; j < curve2.length; j++) {
            results[i].push(-1);
        }
    }
    var recursiveCalc = function (i, j) {
        if (results[i][j] > -1)
            return results[i][j];
        if (i === 0 && j === 0) {
            results[i][j] = geometry_1.pointDistance(curve1[0], curve2[0]);
        }
        else if (i > 0 && j === 0) {
            results[i][j] = Math.max(recursiveCalc(i - 1, 0), geometry_1.pointDistance(curve1[i], curve2[0]));
        }
        else if (i === 0 && j > 0) {
            results[i][j] = Math.max(recursiveCalc(0, j - 1), geometry_1.pointDistance(curve1[0], curve2[j]));
        }
        else if (i > 0 && j > 0) {
            results[i][j] = Math.max(Math.min(recursiveCalc(i - 1, j), recursiveCalc(i - 1, j - 1), recursiveCalc(i, j - 1)), geometry_1.pointDistance(curve1[i], curve2[j]));
        }
        else {
            results[i][j] = Infinity;
        }
        return results[i][j];
    };
    return recursiveCalc(curve1.length - 1, curve2.length - 1);
};
exports.default = frechetDist;
//# sourceMappingURL=frechetDistance.js.map